@@ -3,9 +3,6 @@ from hashlib import md5
 from typing import Optional, Tuple
 import textwrap
 
-from django.db.models import ForeignKey, ManyToManyField
-from model_utils import Choices
-
 CHOICES_COLOR = '#EEE'
 AUTO_FIELDS = {"AutoField", "AutoLastModifiedField", "AutoCreatedField"}
 
@@ -48,6 +45,7 @@ class PlantUml:
             with_legend=False,
             with_help=True,
             with_choices=True,
+            omit_history=True,
             include=None,
             omit=None,
             with_omitted_headers=False,
@@ -58,6 +56,7 @@ class PlantUml:
         self.with_legend = with_legend
         self.with_help = with_help
         self.with_choices = with_choices
+        self.omit_history = omit_history
         self.include = include
         self.omit = omit
         self.with_omitted_headers = with_omitted_headers
@@ -74,6 +73,16 @@ class PlantUml:
         """
         return str(model._meta.label).startswith(app_name + '.')
 
+    @staticmethod
+    def is_historical(model) -> bool:
+        """
+        Checks is model a django-simple-history historical model or not.
+        True if somehow inherited from simple_history classes
+        :param model: django model instance
+        :return:
+        """
+        return any(['simple_history.' in str(m) for m in model.__mro__])
+
     def is_allowed_related(self, related) -> bool:
         """
         Checks is related class have to be rendered or not.
@@ -162,7 +171,7 @@ class PlantUml:
         """
         if field.choices:
             choices = field.choices
-            if isinstance(choices, Choices):
+            if type(choices).__name__ == 'Choices':
                 return choices._display_map
             elif isinstance(choices, tuple):
                 return {k: (k, v) for k, v in choices}
@@ -227,9 +236,9 @@ class PlantUml:
         :param field: django model field
         :return: django model
         """
-        if isinstance(field, ForeignKey):
+        if type(field).__name__ == 'ForeignKey':
             return field.foreign_related_fields[0].model
-        elif isinstance(field, ManyToManyField):
+        elif type(field).__name__ == 'ManyToManyField':
             return field.target_field.model
 
     def model_relations_repr(self, meta) -> str:
@@ -245,11 +254,11 @@ class PlantUml:
         fields = list(meta.fields)
         fields.extend(meta.many_to_many)
         # generate links to related models
-        for related in list(filter(lambda x: isinstance(x, ForeignKey), fields)):
+        for related in list(filter(lambda x: type(x).__name__ == 'ForeignKey', fields)):
             if self.with_omitted_headers or self.is_allowed_related(related):
                 related_meta = related.foreign_related_fields[0].model._meta
                 uml += f'{meta.label} {foreign_line} {related_meta.label}\n'
-        for related in list(filter(lambda x: isinstance(x, ManyToManyField), fields)):
+        for related in list(filter(lambda x: type(x).__name__ == 'ManyToManyField', fields)):
             if self.with_omitted_headers or self.is_allowed_related(related):
                 related_meta = related.target_field.model._meta
                 uml += f'{meta.label} {many_to_many_line} {related_meta.label}\n'
@@ -282,6 +291,9 @@ class PlantUml:
                 continue
             if self.include and all([not self.is_app_member(model, to_include) for to_include in self.include]):
                 continue
+            # or historical if omit_history
+            if self.omit_history and self.is_historical(model):
+                continue
             model_uml, model_choices = self.model_repr(model)
             uml += model_uml
             # collect model choices to future processing
